"use client";

import { useEffect, useState } from "react";
import Link from "next/link";
import sal from "sal.js";

import CategoryOne from "../Category/CategoryOne";
import MainDemoBanner from "./MainDemoBanner";
import Card from "../Cards/Card";
import AboutTwo from "../Abouts/About-Two";
import CallToAction from "../Call-To-Action/CallToAction";
import Counter from "../Counters/Counter";
import TestimonialSeven from "../Testimonials/Testimonial-Seven";
import EventCarouse from "../Events/EventCarouse";
import TeamTwo from "../Team/TeamTwo";
import BlogGridTop from "../Blogs/Blog-Sections/BlogGrid-Top";
import NewsletterTwo from "../Newsletters/Newsletter-Two";

import { ParallaxProvider } from "react-scroll-parallax";


const MainDemo = ({ blogs }) => {

  // Courses
  const [courses, setCourses] = useState([]);
  const [coursesPage, setCoursesPage] = useState(1);
  const [coursesLimit, setCoursesLimit] = useState(5);
  const [coursesPagination, setCoursesPagination] = useState({});
  const [coursesLoading, setCoursesLoading] = useState(true);

  // About Us
  const [aboutUs, setAboutUs] = useState({});

  // Review
  const [review, setReview] = useState([]);

  // Instructors
  const [instructors, setInstructors] = useState([]);
  const [instructorsLoading, setInstructorsLoading] = useState(true);


  useEffect(() => {
    sal({
      threshold: 0.01,
      once: true,
    });
  });

  useEffect(() => {
    return () => {
      getCourses();
      getAboutUs();
      getReview();
      getInstructors();
    }
  }, []);

  // Get Courses
  const getCourses = async () => {
    try {
      setCoursesPage(prevPage => ++prevPage);
      let response = await global.api.GET_METHOD(`Courses?limit=${coursesLimit}&page=${coursesPage}`);
      console.log("Courses", response);
      setCoursesPagination(response.data.meta);
      setCourses(prevData => [...prevData, ...response.data.data]);
    } catch (error) {
      console.error("Error fetching courses:", error);
    } finally {
      setCoursesLoading(false);
    }
  };

  // Get About Us
  const getAboutUs = async () => {
    try {
      let response = await global.api.GET_METHOD(`about_us`);
      console.log("About Us", response.data);
      setAboutUs(response.data);
    } catch (error) {
      console.error("Error fetching About Us:", error);
    }
  };

  // Get Review
  const getReview = async () => {
    try {
      let response = await global.api.GET_METHOD(`review`);
      console.log("review", response.data);
      setReview(response.data);
    } catch (error) {
      console.error("Error fetching review:", error);
    }
  };

  // Get instructors
  const getInstructors = async () => {
    try {
      let response = await global.api.GET_METHOD(`instructors`);
      response.data.forEach((instructor, index) => {
        !index ? instructor.isActive = true : instructor.isActive = false
      });
      console.log("instructors", response.data);
      setInstructors(response.data);
    } catch (error) {
      console.error("Error fetching Instructors:", error);
    } finally {
      setInstructorsLoading(false);
    }
  };

  const handleLoadMoreCourse = () => {
    if (coursesPagination.last_page >= coursesPage) {
      getCourses();
    }
  };

  return (
    <>
      <main className="rbt-main-wrapper">
        <div className="rbt-banner-area rbt-banner-1">
          <MainDemoBanner />
        </div>

        <div className="rbt-categories-area bg-color-white rbt-section-gapBottom">
          <div className="container">
            <div className="row">
              <div className="col-lg-12">
                <div className="section-title text-center">
                  <span className="subtitle bg-primary-opacity">
                    CATEGORIES
                  </span>
                  <h2 className="title">
                    Explore Top Courses Caterories <br /> That Change Yourself
                  </h2>
                </div>
              </div>
            </div>
            <div className="row g-5 mt--20">
              <CategoryOne />
            </div>
          </div>
        </div>

        <div className="rbt-course-area bg-color-extra2 rbt-section-gap">
          <div className="container">
            <div className="row mb--60">
              <div className="col-lg-12">
                <div className="section-title text-center">
                  <span className="subtitle bg-secondary-opacity">
                    Top Popular Course
                  </span>
                  <h2 className="title">
                    Histudy Course student <br /> can join with us.
                  </h2>
                </div>
              </div>
            </div>
            <div className="row row--15">
              <Card
                col="col-lg-4 col-md-6 col-sm-6 col-12"
                mt="mt--30"
                start={0}
                end={coursesPagination.total}
                isDesc={true}
                isUser={true}
                data={courses}
                isLoading={coursesLoading}
              />
            </div>
            {courses?.length !== coursesPagination.total &&
              <div className="row">
                <div className="col-lg-12">
                  <div className="load-more-btn mt--60 text-center">

                    <div
                      className="rbt-btn btn-gradient btn-lg hover-icon-reverse"
                      style={{ cursor: "pointer" }}
                      onClick={handleLoadMoreCourse}
                    >
                      <span className="icon-reverse-wrapper">
                        <span className="btn-text">Load More Course ({coursesPagination.total})</span>
                        <span className="btn-icon">
                          <i className="feather-arrow-right"></i>
                        </span>
                        <span className="btn-icon">
                          <i className="feather-arrow-right"></i>
                        </span>
                      </span>
                    </div>
                  </div>
                </div>
              </div>
            }
          </div>
        </div>

        <div className="rbt-about-area bg-color-white rbt-section-gapTop pb_md--80 pb_sm--80 about-style-1">
          <div className="container">
            <ParallaxProvider>
              <AboutTwo responseData={aboutUs} />
            </ParallaxProvider>
          </div>
        </div>

        <div className="rbt-callto-action-area mt_dec--half">
          <CallToAction responseData={aboutUs} />
        </div>

        <div className="rbt-counterup-area bg-color-extra2 rbt-section-gapBottom default-callto-action-overlap">
          <div className="container">
            <Counter responseData={aboutUs} isDesc={false} />
          </div>
        </div>

        <div className="rbt-testimonial-area bg-color-white rbt-section-gap overflow-hidden">
          <div className="wrapper">
            <div className="container">
              <div className="row">
                <div className="col-lg-12">
                  <div className="section-title text-center mb--10">
                    <span className="subtitle bg-primary-opacity">
                      EDUCATION FOR EVERYONE
                    </span>
                    <h2 className="title">
                      People like histudy education. <br /> No joking - here’s
                      the proof!
                    </h2>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <TestimonialSeven responseData={review} />
        </div>

        {/* <div className="rbt-event-area rbt-section-gap bg-gradient-3">
          <div className="container">
            <div className="row mb--55">
              <div className="section-title text-center">
                <span className="subtitle bg-white-opacity">
                  STIMULATED TO TAKE PART IN?
                </span>
                <h2 className="title color-white">Upcoming Events</h2>
              </div>
            </div>
            <div className="row">
              <div className="col-lg-12">
                <EventCarouse />
              </div>
            </div>
          </div>
        </div> */}

        <div className="rbt-team-area bg-color-white rbt-section-gap">
          <div className="container">
            <div className="row mb--60">
              <div className="col-lg-12">
                <div className="section-title text-center">
                  <span className="subtitle bg-primary-opacity">
                    Our Teacher
                  </span>
                  <h2 className="title">Whose Inspirations You</h2>
                </div>
              </div>
            </div>
            <TeamTwo
              responseData={instructors}
              isLoading={instructorsLoading}
            />
          </div>
        </div>

        {/* <div className="rbt-rbt-blog-area rbt-section-gap bg-color-extra2">
          <div className="container">
            <div className="row g-5 align-items-center mb--30">
              <div className="col-lg-6 col-md-6 col-12">
                <div className="section-title">
                  <span className="subtitle bg-pink-opacity">Blog Post</span>
                  <h2 className="title">Post Popular Post.</h2>
                </div>
              </div>
              <div className="col-lg-6 col-md-6 col-12">
                <div className="read-more-btn text-start text-md-end">
                  <Link
                    className="rbt-btn btn-gradient hover-icon-reverse"
                    href="/blog"
                  >
                    <div className="icon-reverse-wrapper">
                      <span className="btn-text">See All Articles</span>
                      <span className="btn-icon">
                        <i className="feather-arrow-right"></i>
                      </span>
                      <span className="btn-icon">
                        <i className="feather-arrow-right"></i>
                      </span>
                    </div>
                  </Link>
                </div>
              </div>
            </div>
            <BlogGridTop BlogData={blogs} />
          </div>
        </div> */}

        <div className="rbt-newsletter-area newsletter-style-2 bg-color-primary rbt-section-gap">
          <NewsletterTwo />
        </div>
      </main>
    </>
  );
};

export default MainDemo;
