import Image from "next/image";
import Link from "next/link";
import loading_img from "../../public/images/get_data_loader.svg";

const Card = ({ start, end, col, mt, isDesc, isUser , data , isLoading }) => {

  if (isLoading) {
    return <div className="d-flex justify-content-center align-self-center" style={{ height: '95dvh' }}><Image src={loading_img} width={100} height={100} alt="Loading Image" /></div>
  }

  if (!data?.length) {
    return <div>No cards available</div>;
  }

  return (
    <>
    {/* {CourseDetails &&CourseDetails.courseDetails} */}
      {data.slice(start, end).map((data, index) => (
       
          <div
            className={`${col} ${mt}`}
            data-sal-delay="150"
            data-sal="slide-up"
            data-sal-duration="800"
            key={index}
          >
            <div className="rbt-card variation-01 rbt-hover">
              <div className="rbt-card-img">
                <Link href={`/course-details/${data?.id}`}>
                {/* data?.courseImg */}
                  <Image
                    src={data?.image || ''}
                    width={355}
                    height={244}
                    alt="Card image"
                  />
                  {/* data?.offPrice */}
                  {data?.discount > 0 ? (
                    <div className="rbt-badge-3 bg-white">
                      <span>-{data?.discount}</span>
                      <span>Off</span>
                    </div>
                  ) : (
                    ""
                  )}
                </Link>
              </div>
              <div className="rbt-card-body">
                <div className="rbt-card-top">
                  <div className="rbt-review">
                    <div className="rating">
                      {Array.from({ length: data?.rate }).map(rate =>
                      (<i className="fas fa-star"></i>))}
                    </div>
                    <span className="rating-count">
                    {/* {data?.review} */}
                      ({data?.rate_count} Reviews)
                    </span>
                  </div>
                  <div className="rbt-bookmark-btn">
                    <Link className="rbt-round-btn" title="Bookmark" href="#">
                      <i className="feather-bookmark"></i>
                    </Link>
                  </div>
                </div>

                <h4 className="rbt-card-title">
                  <Link href={`/course-details/${data?.id}`}>
                    {/* {data?.courseTitle} */}
                    {data?.title}
                  </Link>
                </h4>

                <ul className="rbt-meta">
                  <li>
                    <i className="feather-book"></i>
                    {/* {data?.lesson} Lessons */}
                    {data?.lessons_count} Lessons
                  </li>
                  <li>
                    <i className="feather-users"></i>
                    {/* {data?.student} Students */}
                    {data?.users_count} Students
                  </li>
                </ul>
                {isDesc ? <p className="rbt-card-text">{data?.desc}</p> : ""}
                {isUser ? (
                  <div className="rbt-author-meta mb--10">
                    <div className="rbt-avater">
                      <Link href={`/profile/${data?.id}`}>
                      {/* {data?.userImg} */}
                        <Image
                          src={data?.image || ''}
                          width={33}
                          height={33}
                          alt="Sophia Jaymes"
                        />
                      </Link>
                    </div>
                    <div className="rbt-author-info">
                      By{data?.instructor}
                      <Link href={`/profile/${data?.id}`}>{data?.userName}</Link>{" "}
                      In <Link href="#">{data?.instructor}</Link>
                    </div>
                  </div>
                ) : (
                  ""
                )}
                <div className="rbt-card-bottom">
                  <div className="rbt-price">
                    <span className="current-price">${data?.price}</span>
                    <span className="off-price">${data?.discount}</span>
                  </div>
                  {data?.button ? (
                    <Link
                      className="rbt-btn-link left-icon"
                      href={`/course-details/${data?.id}`}
                    >
                      <i className="feather-shopping-cart"></i> Add To Cart
                    </Link>
                  ) : (
                    <Link
                      className="rbt-btn-link"
                      href={`/course-details/${data?.id}`}
                    >
                      Learn More<i className="feather-arrow-right"></i>
                    </Link>
                  )}
                </div>
              </div>
            </div>
          </div>
        ))}
    </>
  );
};

export default Card;
