"use client";

import Image from "next/image";
import Link from "next/link";

import CourseDetails from "../../data/course-details/courseData.json";
import useCategoryCount from "@/context/useCategoryCount";
import loading_img from "../../public/images/get_data_loader.svg";
import default_img from "../../public/images/category/infographic.png";

import { useState, useEffect } from 'react'

const CategoryOne = () => {
  const { categoryCounts } = useCategoryCount(CourseDetails.courseDetails);

  const [isLoading, setLoading] = useState(true);
  const [categories, setCategories] = useState([]);
  const [imageError, setImageError] = useState(false);

  useEffect(() => {
    return () => { getData(); }
  }, []);

  const getData = async () => {
    let response =  await global.api.GET_METHOD('categories')
    console.log("CategoryOne", response);
    setCategories(response.data);
    setLoading(false)
  }

  if (isLoading) {
    return <div className="d-flex justify-content-center align-self-center" style={{ height: '95dvh' }}><Image src={loading_img} width={100} height={100} alt="Loading Image" /></div>
  }

  if (!categories.length) {
    return <div>No categories available</div>;
  }

  return (
    <>
      {categories.slice(0, 8).map((item, innerIndex) => {
        return (
          <div className="col-lg-3 col-md-6 col-sm-6 col-12" key={innerIndex}>
            <Link
              className="rbt-cat-box rbt-cat-box-1 text-center"
              href={`/course-filter-one-toggle/${item?.name}`}
            >
              <div className="inner">
                <div className="icons">
                  <Image
                    src={item?.image || ''}
                    width={80}
                    height={80}
                    priority
                    alt="Icons Images"
                  />
                </div>
                <div className="content">
                  <h5 className="title">{item?.name}</h5>
                  <div className="read-more-btn">
                    <span className="rbt-btn-link">
                      {item?.courses_count} Course{item?.courses_count !== 1 ? "s" : ""}
                      <i className="feather-arrow-right"></i>
                    </span>
                  </div>
                </div>
              </div>
            </Link>
          </div>
        );
      })}
    </>
  );
};

export default CategoryOne;
