"use client";

import Image from "next/image";
import dynamic from "next/dynamic";

import CounterHead from "./Counter-Head";

import CounterData from "../../data/elements/counter.json";
import useFetch from "@/context/useFetch";

const Odometer = dynamic(() => import("react-odometerjs"), {
  ssr: false,
  loading: () => <span>00</span>,
});

const Counter = ({ responseData, isDesc, head }) => {
  const { values } = useFetch(CounterData, "counterOne");

  return (
    <>
      <div className="container">
        <CounterHead
          bgClass="bg-primary-opacity"
          mb="mb--40"
          tag={'WHY CHOOSE US'}
          title={'Creating A Community Of'}
          subTitle={'Life Long Learners.'}
          desc={isDesc ? 'There are many variations of passages of the Ipsum available, but the majority have suffered alteration in some form, by injected humour.' : ""}
        />

        <div className="row g-5 hanger-line">

          {/* start learners counting */}
          <div className='col-lg-3 col-md-6 col-sm-6 col-12 mt_md--60 mt_sm--60' >
            <div className="rbt-counterup rbt-hover-03 border-bottom-gradient">
              <div className="top-circle-shape"></div>
              <div className="inner">
                <div className="rbt-round-icon">
                  <Image
                    src={'/images/icons/counter-01.png'}
                    width={50}
                    height={50}
                    alt="Icons Images"
                  />
                </div>
                <div className="content">
                  <h3 className="counter">
                    <span className="odometer">
                      <Odometer value={responseData.learners_counting} />
                    </span>
                  </h3>
                  <span className="subtitle">{'Learners & counting'}</span>
                </div>
              </div>
            </div>
          </div>
          {/* end learners counting */}

          {/* start Courses & Video */}
          <div className='col-lg-3 col-md-6 col-sm-6 col-12 mt--60 mt_md--30 mt_sm--30 mt_mobile--60' >
            <div className="rbt-counterup rbt-hover-03 border-bottom-gradient">
              <div className="top-circle-shape"></div>
              <div className="inner">
                <div className="rbt-round-icon">
                  <Image
                    src={'/images/icons/counter-02.png'}
                    width={50}
                    height={50}
                    alt="Icons Images"
                  />
                </div>
                <div className="content">
                  <h3 className="counter">
                    <span className="odometer">
                      <Odometer value={responseData.courses_video_counting} />
                    </span>
                  </h3>
                  <span className="subtitle">{'Courses & Video'}</span>
                </div>
              </div>
            </div>
          </div>
          {/* end Courses & Video */}

          {/* start Certified Students */}
          <div className='col-lg-3 col-md-6 col-sm-6 col-12 mt_md--60 mt_sm--60' >
            <div className="rbt-counterup rbt-hover-03 border-bottom-gradient">
              <div className="top-circle-shape"></div>
              <div className="inner">
                <div className="rbt-round-icon">
                  <Image
                    src={'/images/icons/counter-03.png'}
                    width={50}
                    height={50}
                    alt="Icons Images"
                  />
                </div>
                <div className="content">
                  <h3 className="counter">
                    <span className="odometer">
                      <Odometer value={responseData.certified_students_counting} />
                    </span>
                  </h3>
                  <span className="subtitle">{'Certified Students'}</span>
                </div>
              </div>
            </div>
          </div>
          {/* end Certified Students */}

          {/* start Registered Enrolls */}
          <div className='col-lg-3 col-md-6 col-sm-6 col-12 mt--60 mt_md--30 mt_sm--30 mt_mobile--60' >
            <div className="rbt-counterup rbt-hover-03 border-bottom-gradient">
              <div className="top-circle-shape"></div>
              <div className="inner">
                <div className="rbt-round-icon">
                  <Image
                    src={'/images/icons/counter-04.png'}
                    width={50}
                    height={50}
                    alt="Icons Images"
                  />
                </div>
                <div className="content">
                  <h3 className="counter">
                    <span className="odometer">
                      <Odometer value={responseData.registered_enrolls_counting} />
                    </span>
                  </h3>
                  <span className="subtitle">{'Registered Enrolls'}</span>
                </div>
              </div>
            </div>
          </div>
          {/* end Registered Enrolls */}

        </div>
      </div>
    </>
  );
};

export default Counter;
