import Image from "next/image";
import Link from "next/link";
import loading_img from "../../public/images/get_data_loader.svg";
import TeamData from "../../data/elements/team.json";

const TeamTwo = ({responseData, isLoading}) => {

  if (isLoading) {
    return <div className="d-flex justify-content-center align-self-center" style={{ height: '95dvh' }}><Image src={loading_img} width={100} height={100} alt="Loading Image" /></div>
  }

  if (!responseData?.length) {
    return <div>No Instructors available</div>;
  }

  return (
    <>
      <div className="row g-5">
        <div className="col-lg-7">
          <div className="rbt-team-tab-content tab-content" id="myTabContent">
            {responseData.map((data, index) => (
                <div
                  className={`tab-pane fade ${data?.isActive ? "active" : ""} show`}
                  id={`team-tab${index}`}
                  role="tabpanel"
                  aria-labelledby={`team-tab${index}-tab`}
                  key={index}
                >
      
                    <div className="inner" >
                      <div className="rbt-team-thumbnail">
                        <div className="thumb">
                          <Image
                            src={data?.avatar || ''}
                            width={415}
                            height={555}
                            priority
                            alt="Testimonial Images"
                          />
                        </div>
                      </div>
                      <div className="rbt-team-details">
                        <div className="author-info">
                          <h4 className="title">{data?.first_name} {data?.last_name}</h4>
                          <span className="designation theme-gradient">
                            {data?.public_name}
                          </span>
                          {/* <span className="team-form">
                            <i className="feather-map-pin"></i>
                            <span className="location">{data?.location}</span>
                          </span> */}
                        </div>
                        <p>{data?.bio}</p>
                        <ul className="social-icon social-default mt--20 justify-content-start">
                          <li>
                            <Link href={data?.facebook} target="_blank">
                              <i className="feather-facebook"></i>
                            </Link>
                          </li>
                          <li>
                            <Link  href={data?.twitter} target="_blank">
                              <i className="feather-twitter"></i>
                            </Link>
                          </li>
                          <li>
                            <Link  href={data?.facebook} target="_blank">
                              <i className="feather-github"></i>
                            </Link>
                          </li>
                        </ul>
                        <ul className="rbt-information-list mt--25">
                          <li>
                            <Link href="#">
                              <i className="feather-phone"></i>
                              {data?.phone}
                            </Link>
                          </li>
                          <li>
                            <Link href={`mailto:${data?.email}`}>
                              <i className="feather-mail"></i>
                              {data?.email}
                            </Link>
                          </li>
                        </ul>
                      </div>
                    </div>
                </div>
              ))}
            <div className="top-circle-shape"></div>
          </div>
        </div>

        <div className="col-lg-5">
          <ul
            className="rbt-team-tab-thumb nav nav-tabs"
            id="myTab"
            role="tablist">
            {responseData.slice(0, 6).map((data, index) => (
                <li key={index}>
                  <Link
                    className={`${data?.isActive ? "active" : ""}`}
                    id={`team-tab${index}-tab`}
                    data-bs-toggle="tab"
                    data-bs-target={`#team-tab${index}`}
                    role="tab"
                    aria-controls={`team-tab${index}`}
                    aria-selected={data?.isActive}
                    href="#"
                  >
                    <div className="rbt-team-thumbnail">
                      <div className="thumb">
                        <Image
                          src={data?.avatar}
                          width={415}
                          height={555}
                          priority
                          alt="Testimonial Images"
                        />
                      </div>
                    </div>
                  </Link>
                </li>
              ))}
          </ul>
        </div>
      </div>
    </>
  );
};

export default TeamTwo;
