import toast from 'react-hot-toast';


const API_URL = 'https://edu.negmaraba.com/api/'; /* process.env.API_URL */

export const GET_METHOD = async (END_POINT) => {
  try {
    let res = await fetch(`${API_URL}${END_POINT}`, {
      method: 'GET',
      headers: {
        "Accept": "application/json",
        "Accept-Language": "ar",
      }
    });

    // Check if the response is ok (status in the range 200-299)
    if (!res.ok) {
      console.log('!res.ok', res);
      let error = await res.json()
      console.log('!res.ok error', error);
      toast.error(error?.message);
      throw new Error(`HTTP error! status: ${res.status}`);
    }

    let response = await res.json();
    return response;

  } catch (error) {
    // Handle errors, log or throw them as necessary
    console.error("Error occurred while fetching data:", error);
    throw error; // re-throw the error if you want it to propagate
  }
};

export const POST_METHOD = async (END_POINT, DATA) => {
  console.log("DATA", DATA);
  try {
    let res = await fetch(`${API_URL}${END_POINT}`, {
      method: 'POST',
      body: DATA,
      // body: JSON.stringify(DATA),
      headers: {
        "Accept": "application/json",
        "Accept-Language": "ar",
      }
    });

    // Check if the response is ok (status in the range 200-299)
    if (!res.ok) {
      throw new Error(`HTTP error! status: ${res.status}`);
    }

    let response = await res.json();
    return response;

  } catch (error) {
    // Handle errors, log or throw them as necessary
    console.error("Error occurred while fetching data:", error);
    toast.error(error?.message);
    throw error; // re-throw the error if you want it to propagate
  }
};

export const POST_FORM_METHOD = async (END_POINT, DATA) => {
  // Create a FormData object
  const formData = new FormData();
  
  // Append the data to the FormData object
  for (const key in DATA) {
    formData.append(key, DATA[key]);
  }

  try {
    let res = await fetch(`${API_URL}${END_POINT}`, {
      method: 'POST',
      body: formData,
      headers: {
        "Accept": "application/json",
        "Accept-Language": "ar",
      }
    });

    // Check if the response is ok (status in the range 200-299)
    if (!res.ok) {
      console.log('!res.ok', res);
      let error = await res.json()
      console.log('!res.ok error', error);
      toast.error(error?.message);
      throw new Error(`HTTP error! status: ${res.status}`);
    }

    let response = await res.json();
    toast.success(response?.message);
    return response;

  } catch (error) {
    // Handle errors, log or throw them as necessary
    console.log('error', error);
    console.error("Error occurred while fetching data:", error);
    throw error; // re-throw the error if you want it to propagate
  }
};


export const FormDataMethod= (DATA) => {
  const formData = new FormData();
  for (const key in DATA) {
    if (Array.isArray(DATA[key]) && DATA[key].length) {
      DATA[key].forEach((attachment, index) => {
        if (typeof attachment === 'object' && !(attachment instanceof File)) {
          for (let obj in attachment) {
            formData.append(`${key}[${index}].${obj}`, attachment[obj]);
          }
        } else {
          formData.append(`${key}[${index}]`, attachment);
        }
      })
    }
    else if (typeof DATA[key] === 'object' && DATA[key] !== null && !(DATA[key] instanceof File)) {
      for (const subKey in DATA[key]) {
        if (Array.isArray(DATA[key][subKey]) && DATA[key][subKey].length) {
          DATA[key][subKey].forEach((attachment, index) => {
            if (typeof attachment === 'object' && !(attachment instanceof File)) {
              for (let obj in attachment) {
                formData.append(`${key}.${subKey}[${index}].${obj}`, attachment[obj]);
              }
            } else {
              formData.append(`${key}.${subKey}[${index}]`, attachment);
            }
          })
        } else {
          DATA[key][subKey] && formData.append(`${key}.${subKey}`, DATA[key][subKey])
        }
      }
    }
    else {
      if (Array.isArray(DATA[key]) && !DATA[key].length) {
        false
      } else {
        formData.append(key, DATA[key])
      }
    }
  }

  return formData
}
